Learn R Programming

pcoxtime (version 1.0.4)

coef.pcoxtime: Extract coefficient estimates of pcoxtime object

Description

This function extracts the estimates for all the coefficients.

Usage

# S3 method for pcoxtime
coef(object, ...)

# S3 method for pcoxtime coefficients(object, ...)

Arguments

object

fitted pcoxtime model object

...

for future implementations

Value

A vector of coefficient estimates.

A vector of coefficient estimates.

Details

The call that produced pcoxtime is printed, followed by coefficient estimates.