Extract cross-validation summaries and data frames.
# S3 method for pcoxtimecv
extractoptimal(object, what = c("optimal", "cvm", "coefs"), ...)pcoxtimecv object
the summary or data frame to extract. Currently, three options are available: what = "optimal" extracts a data frame showing optimal parameter values, what = "cvm" extracts the data frame containing the mean cross-validation error for various lambda-alpha combination, and what = "coef", requires refit = TRUE in pcoxtimecv, extracts a data frame containing the coefficient estimates for various lambda-alpha combination.
for future implementations
A data frame depending on the specification described above.
Extract cross-validation summaries based on the optimal parameters or data frames containing all the summaries for all the parameter values.