This function prints a summary of the pcoxtime object.
# S3 method for pcoxtime
print(x, ..., nprint = 10)fitted pcoxtime model object
for future implementations
number of coefficients to print out
A two column output, the first column is the coefficient estimate and the second column is the exponent of the coefficient estimate. Additonal summary about the number of nonzero coefficents, the number of observations and the number of event of interest are also printed.
The call that produced pcoxtime is printed, followed by coefficient estimates with their corresponding exponentiated values.
Depending on the number of coefficients, nprint can be used to specify the number of coefficients to print out.