Learn R Programming

pcoxtime (version 1.0.4)

print.pcoxtimecv: Print cross-validated pcoxtime object

Description

Print the summary of the result of cross-validation for a pcoxtime object.

Usage

# S3 method for pcoxtimecv
print(x, ...)

Arguments

x

pcoxtimecv object

...

for future implementations

Value

The call to the pcoxtimecv and the summary of the optimal alpha and lambdas.

Details

A summary of optimal lambda and alpha for training pcoxtime model.